@@ -11,11 +11,11 @@ Perl::Critic::Bangs - A collection of handy Perl::Critic policies
 
 =head1 VERSION
 
-Version 1.10
+Version 1.12
 
 =cut
 
-our $VERSION = '1.10';
+our $VERSION = '1.12';
 
 =head1 SYNOPSIS
 
@@ -40,13 +40,18 @@ Tests should have a plan.
 
 =head2 L<Perl::Critic::Policy::Bangs::ProhibitNumberedNames>
 
-Variables like C<$user> and C<$user2> are insufficiently distinguished.
+Subroutines and variables like C<$user> and C<$user2> are insufficiently
+distinguished.
 
 =head2 L<Perl::Critic::Policy::Bangs::ProhibitRefProtoOrProto>
 
 Determining the class in a constructor by using C<ref($proto) || $proto> is usually
 a cut-n-paste that is incorrect.
 
+=head2 L<Perl::Critic::Policy::Bangs::ProhibitUselessTopic>
+
+Explicitly matching or substituting against C<$_> is clutter.
+
 =head2 L<Perl::Critic::Policy::Bangs::ProhibitUselessRegexModifiers>
 
 Adding modifiers to a regular expression made up entirely of a
@@ -54,12 +59,13 @@ variable created with C<qr()> is usually not doing what you expect.
 
 =head2 L<Perl::Critic::Policy::Bangs::ProhibitVagueNames>
 
-Vague variables like C<$data> or C<$info> are not descriptive enough.
+Vague variables and subroutines like C<$data> or C<$info> are not
+descriptive enough.
 
 =head1 WHY IS IT CALLED Perl::Critic::Bangs?
 
 I didn't want to call it "Perl::Critic::Lester" or "Perl::Critic::Petdance"
-that would make it sound like they were only my rules.  Other people
+since that would make it sound like they were only my rules.  Other people
 will likely include their own set of rules, too.
 
 So I started thinking of names of famous critics.  Ebert, Siskel,
@@ -115,22 +121,18 @@ L<http://github.com/petdance/perl-critic-bangs>
 =head1 ACKNOWLEDGMENTS
 
 Thanks to
-
-=over 4
-
-=item * Andy Moore for helping me get this off the ground.
-
-=item * Oystein Torget for bug reports and patches.
-
-=item * Mike O'Regan for ProhibitBitwiseOperators.
-
-=item * Elliot Shank and the rest of the Perl::Critic team for ongoing support.
-
-=back
+William Braswell,
+Oliver Trosien,
+Fred Moyer,
+Andy Moore,
+Oystein Torget,
+Mike O'Regan,
+Elliot Shank
+and the rest of the Perl::Critic team for ongoing support.
 
 =head1 COPYRIGHT
 
-Copyright 2006-2011 Andy Lester.
+Copyright 2006-2017 Andy Lester.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the Artistic License 2.0.
